@@ -5,7 +5,7 @@
 #' a common method of introducing nonlinearity by transforming, usually, covariance structure or
 #' other gram-type estimate to make it flexible in Reproducing Kernel Hilbert Space.
 #'
-#' @param X an \code{(n-by-p)} matrix or data frame whose rows are observations and columns represent independent variables.
+#' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations and columns represent independent variables.
 #' @param ndim an integer-valued target dimension.
 #' @param preprocess an additional option for preprocessing the data.
 #' Default is ``null'', and other methods of ``decorrelate'',``center'' , and ``whiten'' are supported. See also \code{\link{aux.preprocess}} for more details.
@@ -13,15 +13,15 @@
 #'
 #' @return a named list containing
 #' \describe{
-#' \item{Y}{an \code{(n-by-ndim)} matrix whose rows are embedded observations.}
+#' \item{Y}{an \eqn{(n\times ndim)} matrix whose rows are embedded observations.}
 #' \item{trfinfo}{a list containing information for out-of-sample prediction.}
 #' \item{vars}{variances of projected data / eigenvalues from kernelized covariance matrix.}
 #' }
 #'
 #' @examples
+#' \dontrun{
 #' ## generate ribbon-shaped data
-#' ## in order to pass CRAN pretest, n is set to be small.
-#' X = aux.gensamples(dname="ribbon",n=28)
+#' X = aux.gensamples(dname="ribbon",n=123)
 #'
 #' ## 1. standard KPCA with gaussian kernel
 #' output1 <- do.kpca(X,ndim=2)
@@ -37,6 +37,7 @@
 #' plot(output1$Y[,1],output1$Y[,2],main="Gaussian kernel")
 #' plot(output2$Y[,1],output2$Y[,2],main="Gaussian kernel with sigma=5")
 #' plot(output3$Y[,1],output3$Y[,2],main="Laplacian kernel")
+#' }
 #'
 #' @seealso \code{\link{aux.kernelcov}}
 #' @references
@@ -88,7 +89,7 @@ do.kpca <- function(X,ndim=2,preprocess="null",kernel=c("gaussian",1.0)){
 
   # 5. result
   result = list()
-  result$Y = t(t(eigvecs[,1:k]) %*% Koriginal)
+  result$Y = t(t(eigvecs[,1:k]) %*% Kcentered)
   result$trfinfo = trfinfo
   result$vars = (eigvals[1:k])/N
   return(result)
